==> haskell-hxt-charproperties-9.5.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.5.0.0
visibility:           public
id:                   hxt-charproperties-9.5.0.0-9g2utucZe333uNPQXZRzn0
key:                  hxt-charproperties-9.5.0.0-9g2utucZe333uNPQXZRzn0
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks,
    char properties
    and character predicates defined by XML.
    Supported Unicode version is 13.0.0
    9.4.0.0: Supported Unicode version 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  3f9aa30115d3440997e2aa180ae0e489
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hxt-charproperties-9.5.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hxt-charproperties-9.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-charproperties
hs-libraries:         HShxt-charproperties-9.5.0.0-9g2utucZe333uNPQXZRzn0
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.5.0.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hxt-charproperties
version:              9.5.0.0
visibility:           public
id:                   hxt-charproperties-9.5.0.0-JsuB8BVB3oQCkNkgJgjWcz
key:                  hxt-charproperties-9.5.0.0-JsuB8BVB3oQCkNkgJgjWcz
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks,
    char properties
    and character predicates defined by XML.
    Supported Unicode version is 13.0.0
    9.4.0.0: Supported Unicode version 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  c00b64676c913f2d4845dc5483090c35
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hxt-charproperties-9.5.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hxt-charproperties-9.5.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hxt-charproperties-9.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-charproperties
hs-libraries:         HShxt-charproperties-9.5.0.0-JsuB8BVB3oQCkNkgJgjWcz
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
